@@ -5,13 +5,19 @@ import fire
 from wkmake.make import make_from_files,WKMAKE_FILENAME
 from wkmake.pkg_info import pkg_templates_dir,PkgData,TemplatePaths
 from wkmake.utils import export
-
+def is_empty_dir(path):
+    assert os.path.exists(path)
+    assert os.path.isdir(path)
+    return len(os.listdir(path))==0
 class CLI:
     def hi(cls):
         print('Hi, I am wkmake.'.center(50, '*'))
     def makepkg(self,pkg_name):
         if os.path.exists(pkg_name):
-            raise FileExistsError("File or directory already exists: %s"%(pkg_name))
+            try:
+                assert is_empty_dir(pkg_name)
+            except:
+                raise FileExistsError("File or directory already exists: %s"%(pkg_name))
         else:
             os.makedirs(pkg_name)
             shutil.copy(TemplatePaths.wkmake_file_path,os.path.join(pkg_name,WKMAKE_FILENAME))
